: Modified from: /usr/site/nrniv/nrn/src/nrnoc/intfire1.mod
: Modifications:
: - disabled flag added for during-sim disabling / enabling
: - verbose flag added for printout of weights receive by the NET_RECEIVE block
: Last update: 9/14/13 (georgec)

NEURON {
	: ARTIFICIAL_CELL means
	: that this model not only has a NET_RECEIVE block and does NOT
	: have a BREAKPOINT but is not associated with a
	: section location or numerical integrator. i.e it does not
	: refer to v or any ions or have a POINTER. It is entirely isolated
	: and depends on discrete events from the outside to affect it and
	: affects the outside only by sending discrete events.
	ARTIFICIAL_CELL IntFire1b
	RANGE tau, refrac, m, disabled, verbose
	: m plays the role of voltage
}

PARAMETER {
	tau = 10 (ms)
	refrac = 5 (ms)
    disabled = 0       : whether the unit is disabled
    verbose = 0        : verbosity flag    	
}

ASSIGNED {
	m
	t0(ms)
	refractory
}

INITIAL {
	m = 0
	t0 = t
	refractory = 0 : 0-integrates input, 1-refractory
}

FUNCTION M() {
	if (refractory == 0) {
		M = m*exp(-(t - t0)/tau)
	}else if (refractory == 1) {
		if (t - t0 < .5) {
			M = 2
		}else{
			M = -1
		}
	}
}

NET_RECEIVE (w) {
    : Show weight input information if debugging on.
    if (verbose > 0) {
        if (refractory == 0) {
            printf("IntFire1 RECEIVE event: t = %f ms; w = %f\n",t,w)
        } else if (flag != 1) {
            printf("IntFire1 RECEIVE event: t = %f ms; w = %f; in refractory\n",t,w)        
        } else if (flag == 1) {
            printf("IntFire1 RECEIVE event: t = %f ms; end of refractory\n",t)                
        }
    }
    
	if ((refractory == 0) && (disabled == 0)) { : inputs integrated only when excitable
		m = m*exp(-(t - t0)/tau)
		t0 = t
		m = m + w
		if (m > 1) {
			refractory = 1
			m = 2
			net_send(refrac, refractory)
			net_event(t)
		}
	}else if (flag == 1) { : ready to integrate again
		t0 = t
		refractory = 0
		m = 0
	}
}
