"""
sim.py -- Python script for running the simulation interactively

Usage:
  ipython --pylab -i sim/sim.py

Last update: 9/30/13 (georgec)
"""

# Import sys and add the sim subdirectory to the path.
import sys
#sys.path.append('./sim')  # append to the end
sys.path.insert(0, './sim')  # add before first element

# Import os and make sure that './sim' is in the HOC_LIBRARY_PATH.
import os
hlp_str = os.environ['HOC_LIBRARY_PATH']
if  not './sim' in hlp_str:
    print 'Adding ./sim to HOC_LIBRARY_PATH.'
    os.environ['HOC_LIBRARY_PATH'] = hlp_str + ' ./sim'  
    
# Function for determining if a string is a number.
def is_number(s):
    try:
        float(s)
        return True
    except ValueError:
        return False
    except TypeError:
        return False
        
# Function for reading in parameters from the command-line.
def cmdlineparams(theparams):
    # Find the index for the .py script argument.  The first parameter is
    # after that.
    for argind, thearg in enumerate(sys.argv):
        if '.py' in thearg:
            prescriptind = argind
            
    # Grab the parameter names and parameter values, which should alternate
    # in the remaining argv tokens.
    ps = sys.argv[prescriptind + 1::2]
    pvals = sys.argv[prescriptind + 2::2]
    
    # If we happen to be missing the last value for the last parameter, ignore the
    # last parameter.
    if len(pvals) < len(ps):
        ps = ps[0:-1]
        
    # For all of the parameters...
    for pind, thep in enumerate(ps):
        # Check for boolean True.
        if pvals[pind] in ['true', 'True', 't', 'T', 'yes', 'Yes', 'y', 'Y']:
            theparams[thep] = True
        # Check for boolean False.
        elif pvals[pind] in ['false', 'False', 'f', 'F', 'no', 'No', 'n', 'N']:
            theparams[thep] = False
        # Check for floating point value.
        elif is_number(pvals[pind]):
            theparams[thep] = float(pvals[pind])
        # Check to see if likely to be a list or tuple and evaluate if so.
        elif pvals[pind][0] in ['[', '(']:
            theparams[thep] = eval(pvals[pind])
        # If all else fails, interpret as the raw string.
        else:
            theparams[thep] = pvals[pind]
    
# Import hoc and NEURON GUI stuff.
from neuron import h
from neuron import gui

# Import the module for neural units.
import neuralunit as nun

# Load the IntFire1 wrapper module.
import intfire1 as if1

# Import the module for stimulus units.
import stim

# Load the following hoc files which are needed for intf6.
h.load_file("declist.hoc")
h.load_file("decvec.hoc")
h.load_file("labels.hoc")

# Load the INTF6 wrapper module.
import intf6

# Load the Izhikevich unit wrapper module.
import izhiunit as izhi

# Load the following hoc file which are needed for SPICell.
h.load_file("PTcell.hoc")

# Load the SPICell wrapper module.
import SPIcell as spic

# Import the module for neural connections.
import neuralconn as nconn

# Import the module for databases.
import database as db

# Load the NQS hoc code (needed for database).
h.load_file("nqs.hoc")

# Load the unit groups module.
import unitgroups as ugs

# Load the STDP module.
import stdp

# Load the STDP RL module.
import stdp_rl as stdprl

# Load the neuroplot namespace.
from neuroplot import *

# Import all of the functions from the hoc helper module.
from hocinterface import *
